import logging
import sys

import tornado
import zmq
from tornado.web import Application
from tornado.ioloop import IOLoop

from config import WEB_PORT
from handlers import FSMManagingSocketHandler
from sql_injection_fsm import SQLInjectionFSM


class SQLInjectionFSMManagingSocketHandler(FSMManagingSocketHandler):
    def __init__(self, application, request, **kwargs):
        super().__init__(SQLInjectionFSM, application, request, **kwargs)


if __name__ == '__main__':
    routes = [
        (r'/ws', SQLInjectionFSMManagingSocketHandler),
    ]
    application = Application(
        routes,
        autoreload=True
    )

    application.listen(WEB_PORT)
    logging.getLogger().setLevel(logging.DEBUG)
    logging.debug('Python version: {}'.format(sys.version[:5]))
    logging.debug('Tornado version: {}'.format(tornado.version))
    logging.debug('ZeroMQ version: {}'.format(zmq.zmq_version()))
    logging.debug('PyZMQ version: {}'.format(zmq.pyzmq_version()))
    logging.info('Tornado application listening on port {}'.format(WEB_PORT))
    IOLoop.instance().start()
